/// Copyright Thomas Nagy 2007
/// License: QPL

#include <khtml_part.h>
#include <khtmlview.h>
#include <KUrl>
#include <QtDebug>
#include <QLabel>
#include <QTextBrowser>
#include <QCoreApplication>
#include <QWebView>
#include "Prmza.h"
#include "Jelzpn.h"
#include "IztKil.h"
#include "con.h" 
#include "BnvzS.h" 
#include"tslabels.h"

/*!
 * @praise Vishnu
 */
egyklh::egyklh(QWidget *felvnl,jelzpn *megkap) : QStackedWidget(felvnl)
<%
	kidlgz=megkap;

	jlzpnt=new QLabel(this);
	jlzpnt->setText(ts_256);
	addWidget(jlzpnt);

	/*adelk=new KHTMLPart(this,this);
	irnyjl=adelk->widget();
	addWidget(irnyjl);*/
	irnyjl=new QWebView(this);
	addWidget(irnyjl);
%>

void egyklh::kelt(const zagv&tqrost)
<%
	int kivalt=tqrost[3].toInt();
	switch(kivalt)
	<%
		case vadrtc:
			<%
				QString mrtdt=bndkli::fladat(ts_153);
				if(mrtdt.endsWith(ts_257))
				<%
					if(irnyjl->url()==QUrl(mrtdt))
						irnyjl->reload();
					else
					<%
						irnyjl->load(QUrl(mrtdt));
						irnyjl->show();
					%>
					setCurrentWidget(irnyjl);
				%>
				else if(mrtdt.endsWith(ts_258))
				<%
				%>
				else
				<%
					setCurrentWidget(jlzpnt);
				%>
			%>
			break;
		case nytt:
			setCurrentWidget(jlzpnt);
			break;
		default:
			break;
	%>
%>

#include "IztKil.moc"

